@@ -26,12 +26,14 @@ if HAS_GEOIP:
 # 'GeoLiteCity.dat'.
 
 
-@skipUnless(HAS_GEOIP and getattr(settings, "GEOIP_PATH", None),
-    "GeoIP is required along with the GEOIP_PATH setting.")
+@skipUnless(
+    HAS_GEOIP and getattr(settings, "GEOIP_PATH", None),
+    "GeoIP is required along with the GEOIP_PATH setting."
+)
 @ignore_warnings(category=RemovedInDjango20Warning)
 class GeoIPTest(unittest.TestCase):
-    addr = '128.249.1.1'
-    fqdn = 'tmc.edu'
+    addr = '162.242.220.127'
+    fqdn = 'www.djangoproject.com'
 
     def _is_dns_available(self, domain):
         # Naive check to see if there is DNS available to use.
@@ -66,23 +68,29 @@ class GeoIPTest(unittest.TestCase):
         # Improper parameters.
         bad_params = (23, 'foo', 15.23)
         for bad in bad_params:
-            self.assertRaises(GeoIPException, GeoIP, cache=bad)
+            with self.assertRaises(GeoIPException):
+                GeoIP(cache=bad)
             if isinstance(bad, six.string_types):
                 e = GeoIPException
             else:
                 e = TypeError
-            self.assertRaises(e, GeoIP, bad, 0)
+            with self.assertRaises(e):
+                GeoIP(bad, 0)
 
     def test02_bad_query(self):
         "Testing GeoIP query parameter checking."
         cntry_g = GeoIP(city='<foo>')
         # No city database available, these calls should fail.
-        self.assertRaises(GeoIPException, cntry_g.city, 'google.com')
-        self.assertRaises(GeoIPException, cntry_g.coords, 'yahoo.com')
+        with self.assertRaises(GeoIPException):
+            cntry_g.city('google.com')
+        with self.assertRaises(GeoIPException):
+            cntry_g.coords('yahoo.com')
 
         # Non-string query should raise TypeError
-        self.assertRaises(TypeError, cntry_g.country_code, 17)
-        self.assertRaises(TypeError, cntry_g.country_name, GeoIP)
+        with self.assertRaises(TypeError):
+            cntry_g.country_code(17)
+        with self.assertRaises(TypeError):
+            cntry_g.country_name(GeoIP)
 
     def test03_country(self):
         "Testing GeoIP country querying methods."
@@ -119,22 +127,22 @@ class GeoIPTest(unittest.TestCase):
             # City information dictionary.
             d = g.city(query)
             self.assertEqual('USA', d['country_code3'])
-            self.assertEqual('Houston', d['city'])
+            self.assertEqual('San Antonio', d['city'])
             self.assertEqual('TX', d['region'])
-            self.assertEqual(713, d['area_code'])
+            self.assertEqual(210, d['area_code'])
             geom = g.geos(query)
             self.assertIsInstance(geom, GEOSGeometry)
-            lon, lat = (-95.4010, 29.7079)
+            lon, lat = (-98, 29)
             lat_lon = g.lat_lon(query)
             lat_lon = (lat_lon[1], lat_lon[0])
             for tup in (geom.tuple, g.coords(query), g.lon_lat(query), lat_lon):
-                self.assertAlmostEqual(lon, tup[0], 4)
-                self.assertAlmostEqual(lat, tup[1], 4)
+                self.assertAlmostEqual(lon, tup[0], 0)
+                self.assertAlmostEqual(lat, tup[1], 0)
 
     def test05_unicode_response(self):
         "Testing that GeoIP strings are properly encoded, see #16553."
         g = GeoIP()
-        fqdn = "duesseldorf.de"
+        fqdn = "hs-duesseldorf.de"
         if self._is_dns_available(fqdn):
             d = g.city(fqdn)
             self.assertEqual('Düsseldorf', d['city'])
