@@ -3,13 +3,15 @@ from copy import deepcopy
 
 from django.core.exceptions import FieldError, MultipleObjectsReturned
 from django.db import models, transaction
-from django.test import TestCase
+from django.db.utils import IntegrityError
+from django.test import TestCase, ignore_warnings
 from django.utils import six
+from django.utils.deprecation import RemovedInDjango20Warning
 from django.utils.translation import ugettext_lazy
 
 from .models import (
-    Article, Category, Child, First, Parent, Record, Relation, Reporter,
-    School, Student, Third, ToFieldChild,
+    Article, Category, Child, City, District, First, Parent, Record, Relation,
+    Reporter, School, Student, Third, ToFieldChild,
 )
 
 
@@ -21,8 +23,7 @@ class ManyToOneTests(TestCase):
         self.r2 = Reporter(first_name='Paul', last_name='Jones', email='paul@example.com')
         self.r2.save()
         # Create an Article.
-        self.a = Article(id=None, headline="This is a test",
-                         pub_date=datetime.date(2005, 7, 27), reporter=self.r)
+        self.a = Article(headline="This is a test", pub_date=datetime.date(2005, 7, 27), reporter=self.r)
         self.a.save()
 
     def test_get(self):
@@ -37,21 +38,18 @@ class ManyToOneTests(TestCase):
     def test_create(self):
         # You can also instantiate an Article by passing the Reporter's ID
         # instead of a Reporter object.
-        a3 = Article(id=None, headline="Third article",
-                     pub_date=datetime.date(2005, 7, 27), reporter_id=self.r.id)
+        a3 = Article(headline="Third article", pub_date=datetime.date(2005, 7, 27), reporter_id=self.r.id)
         a3.save()
         self.assertEqual(a3.reporter.id, self.r.id)
 
         # Similarly, the reporter ID can be a string.
-        a4 = Article(id=None, headline="Fourth article",
-                     pub_date=datetime.date(2005, 7, 27), reporter_id=str(self.r.id))
+        a4 = Article(headline="Fourth article", pub_date=datetime.date(2005, 7, 27), reporter_id=str(self.r.id))
         a4.save()
         self.assertEqual(repr(a4.reporter), "<Reporter: John Smith>")
 
     def test_add(self):
         # Create an Article via the Reporter object.
-        new_article = self.r.article_set.create(headline="John's second story",
-                                                pub_date=datetime.date(2005, 7, 29))
+        new_article = self.r.article_set.create(headline="John's second story", pub_date=datetime.date(2005, 7, 29))
         self.assertEqual(repr(new_article), "<Article: John's second story>")
         self.assertEqual(new_article.reporter.id, self.r.id)
 
@@ -63,12 +61,10 @@ class ManyToOneTests(TestCase):
 
         self.r.article_set.add(new_article2, bulk=False)
         self.assertEqual(new_article2.reporter.id, self.r.id)
-        self.assertQuerysetEqual(self.r.article_set.all(),
-            [
-                "<Article: John's second story>",
-                "<Article: Paul's story>",
-                "<Article: This is a test>",
-            ])
+        self.assertQuerysetEqual(
+            self.r.article_set.all(),
+            ["<Article: John's second story>", "<Article: Paul's story>", "<Article: This is a test>"]
+        )
 
         # Add the same article to a different article set - check that it moves.
         self.r2.article_set.add(new_article2)
@@ -80,17 +76,14 @@ class ManyToOneTests(TestCase):
             with six.assertRaisesRegex(self, TypeError,
                                        "'Article' instance expected, got <Reporter.*"):
                 self.r.article_set.add(self.r2)
-        self.assertQuerysetEqual(self.r.article_set.all(),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+        self.assertQuerysetEqual(
+            self.r.article_set.all(),
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
 
     def test_set(self):
-        new_article = self.r.article_set.create(headline="John's second story",
-                                                pub_date=datetime.date(2005, 7, 29))
-        new_article2 = self.r2.article_set.create(headline="Paul's story",
-                                                  pub_date=datetime.date(2006, 1, 17))
+        new_article = self.r.article_set.create(headline="John's second story", pub_date=datetime.date(2005, 7, 29))
+        new_article2 = self.r2.article_set.create(headline="Paul's story", pub_date=datetime.date(2006, 1, 17))
 
         # Assign the article to the reporter.
         new_article2.reporter = self.r
@@ -107,27 +100,32 @@ class ManyToOneTests(TestCase):
         # Set the article back again.
         self.r2.article_set.set([new_article, new_article2])
         self.assertQuerysetEqual(self.r.article_set.all(), ["<Article: This is a test>"])
-        self.assertQuerysetEqual(self.r2.article_set.all(),
-            [
-                "<Article: John's second story>",
-                "<Article: Paul's story>",
-            ])
+        self.assertQuerysetEqual(
+            self.r2.article_set.all(),
+            ["<Article: John's second story>", "<Article: Paul's story>"]
+        )
 
         # Funny case - because the ForeignKey cannot be null,
         # existing members of the set must remain.
         self.r.article_set.set([new_article])
-        self.assertQuerysetEqual(self.r.article_set.all(),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+        self.assertQuerysetEqual(
+            self.r.article_set.all(),
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
         self.assertQuerysetEqual(self.r2.article_set.all(), ["<Article: Paul's story>"])
 
+    def test_reverse_assignment_deprecation(self):
+        msg = (
+            "Direct assignment to the reverse side of a related set is "
+            "deprecated due to the implicit save() that happens. Use "
+            "article_set.set() instead."
+        )
+        with self.assertRaisesMessage(RemovedInDjango20Warning, msg):
+            self.r2.article_set = []
+
     def test_assign(self):
-        new_article = self.r.article_set.create(headline="John's second story",
-                                                pub_date=datetime.date(2005, 7, 29))
-        new_article2 = self.r2.article_set.create(headline="Paul's story",
-                                                  pub_date=datetime.date(2006, 1, 17))
+        new_article = self.r.article_set.create(headline="John's second story", pub_date=datetime.date(2005, 7, 29))
+        new_article2 = self.r2.article_set.create(headline="Paul's story", pub_date=datetime.date(2006, 1, 17))
 
         # Assign the article to the reporter directly using the descriptor.
         new_article2.reporter = self.r
@@ -141,76 +139,62 @@ class ManyToOneTests(TestCase):
         ])
         self.assertQuerysetEqual(self.r2.article_set.all(), [])
 
-        # Set the article back again using set descriptor.
-        self.r2.article_set = [new_article, new_article2]
+        # Set the article back again using set() method.
+        self.r2.article_set.set([new_article, new_article2])
         self.assertQuerysetEqual(self.r.article_set.all(), ["<Article: This is a test>"])
-        self.assertQuerysetEqual(self.r2.article_set.all(),
-            [
-                "<Article: John's second story>",
-                "<Article: Paul's story>",
-            ])
+        self.assertQuerysetEqual(
+            self.r2.article_set.all(),
+            ["<Article: John's second story>", "<Article: Paul's story>"]
+        )
 
-        # Funny case - assignment notation can only go so far; because the
-        # ForeignKey cannot be null, existing members of the set must remain.
-        self.r.article_set = [new_article]
-        self.assertQuerysetEqual(self.r.article_set.all(),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+        # Because the ForeignKey cannot be null, existing members of the set
+        # must remain.
+        self.r.article_set.set([new_article])
+        self.assertQuerysetEqual(
+            self.r.article_set.all(),
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
         self.assertQuerysetEqual(self.r2.article_set.all(), ["<Article: Paul's story>"])
         # Reporter cannot be null - there should not be a clear or remove method
         self.assertFalse(hasattr(self.r2.article_set, 'remove'))
         self.assertFalse(hasattr(self.r2.article_set, 'clear'))
 
     def test_selects(self):
-        self.r.article_set.create(headline="John's second story",
-                                  pub_date=datetime.date(2005, 7, 29))
-        self.r2.article_set.create(headline="Paul's story",
-                                   pub_date=datetime.date(2006, 1, 17))
+        self.r.article_set.create(headline="John's second story", pub_date=datetime.date(2005, 7, 29))
+        self.r2.article_set.create(headline="Paul's story", pub_date=datetime.date(2006, 1, 17))
         # Reporter objects have access to their related Article objects.
         self.assertQuerysetEqual(self.r.article_set.all(), [
             "<Article: John's second story>",
             "<Article: This is a test>",
         ])
-        self.assertQuerysetEqual(self.r.article_set.filter(headline__startswith='This'),
-                                 ["<Article: This is a test>"])
+        self.assertQuerysetEqual(self.r.article_set.filter(headline__startswith='This'), ["<Article: This is a test>"])
         self.assertEqual(self.r.article_set.count(), 2)
         self.assertEqual(self.r2.article_set.count(), 1)
         # Get articles by id
-        self.assertQuerysetEqual(Article.objects.filter(id__exact=self.a.id),
-                                 ["<Article: This is a test>"])
-        self.assertQuerysetEqual(Article.objects.filter(pk=self.a.id),
-                                 ["<Article: This is a test>"])
+        self.assertQuerysetEqual(Article.objects.filter(id__exact=self.a.id), ["<Article: This is a test>"])
+        self.assertQuerysetEqual(Article.objects.filter(pk=self.a.id), ["<Article: This is a test>"])
         # Query on an article property
-        self.assertQuerysetEqual(Article.objects.filter(headline__startswith='This'),
-                                 ["<Article: This is a test>"])
+        self.assertQuerysetEqual(Article.objects.filter(headline__startswith='This'), ["<Article: This is a test>"])
         # The API automatically follows relationships as far as you need.
         # Use double underscores to separate relationships.
         # This works as many levels deep as you want. There's no limit.
         # Find all Articles for any Reporter whose first name is "John".
-        self.assertQuerysetEqual(Article.objects.filter(reporter__first_name__exact='John'),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+        self.assertQuerysetEqual(
+            Article.objects.filter(reporter__first_name__exact='John'),
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
         # Check that implied __exact also works
-        self.assertQuerysetEqual(Article.objects.filter(reporter__first_name='John'),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+        self.assertQuerysetEqual(
+            Article.objects.filter(reporter__first_name='John'),
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
         # Query twice over the related field.
         self.assertQuerysetEqual(
-            Article.objects.filter(reporter__first_name__exact='John',
-                                   reporter__last_name__exact='Smith'),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+            Article.objects.filter(reporter__first_name__exact='John', reporter__last_name__exact='Smith'),
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
         # The underlying query only makes one join when a related table is referenced twice.
-        queryset = Article.objects.filter(reporter__first_name__exact='John',
-                                       reporter__last_name__exact='Smith')
+        queryset = Article.objects.filter(reporter__first_name__exact='John', reporter__last_name__exact='Smith')
         self.assertNumQueries(1, list, queryset)
         self.assertEqual(queryset.query.get_compiler(queryset.db).as_sql()[0].count('INNER JOIN'), 1)
 
@@ -218,19 +202,15 @@ class ManyToOneTests(TestCase):
         self.assertQuerysetEqual(
             Article.objects.filter(reporter__first_name__exact='John').extra(
                 where=["many_to_one_reporter.last_name='Smith'"]),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
         # ... and should work fine with the unicode that comes out of forms.Form.cleaned_data
         self.assertQuerysetEqual(
             (Article.objects
                 .filter(reporter__first_name__exact='John')
                 .extra(where=["many_to_one_reporter.last_name='%s'" % 'Smith'])),
-            [
-                "<Article: John's second story>",
-                "<Article: This is a test>",
-            ])
+            ["<Article: John's second story>", "<Article: This is a test>"]
+        )
         # Find all Articles for a Reporter.
         # Use direct ID check, pk check, and object comparison
         self.assertQuerysetEqual(
@@ -284,49 +264,39 @@ class ManyToOneTests(TestCase):
             ])
 
     def test_reverse_selects(self):
-        a3 = Article.objects.create(id=None, headline="Third article",
-                                    pub_date=datetime.date(2005, 7, 27), reporter_id=self.r.id)
-        Article.objects.create(id=None, headline="Fourth article",
-                               pub_date=datetime.date(2005, 7, 27), reporter_id=str(self.r.id))
+        a3 = Article.objects.create(
+            headline="Third article",
+            pub_date=datetime.date(2005, 7, 27),
+            reporter_id=self.r.id,
+        )
+        Article.objects.create(
+            headline="Fourth article",
+            pub_date=datetime.date(2005, 7, 27),
+            reporter_id=self.r.id,
+        )
+        john_smith = ["<Reporter: John Smith>"]
         # Reporters can be queried
-        self.assertQuerysetEqual(Reporter.objects.filter(id__exact=self.r.id),
-                                 ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(Reporter.objects.filter(pk=self.r.id),
-                                 ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(Reporter.objects.filter(first_name__startswith='John'),
-                                 ["<Reporter: John Smith>"])
+        self.assertQuerysetEqual(Reporter.objects.filter(id__exact=self.r.id), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(pk=self.r.id), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(first_name__startswith='John'), john_smith)
         # Reporters can query in opposite direction of ForeignKey definition
-        self.assertQuerysetEqual(Reporter.objects.filter(article__id__exact=self.a.id),
-                                 ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(Reporter.objects.filter(article__pk=self.a.id),
-                                 ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(Reporter.objects.filter(article=self.a.id),
-                                 ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(Reporter.objects.filter(article=self.a),
-                                 ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(
-            Reporter.objects.filter(article__in=[self.a.id, a3.id]).distinct(),
-            ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(
-            Reporter.objects.filter(article__in=[self.a.id, a3]).distinct(),
-            ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(
-            Reporter.objects.filter(article__in=[self.a, a3]).distinct(),
-            ["<Reporter: John Smith>"])
+        self.assertQuerysetEqual(Reporter.objects.filter(article__id__exact=self.a.id), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(article__pk=self.a.id), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(article=self.a.id), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(article=self.a), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(article__in=[self.a.id, a3.id]).distinct(), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(article__in=[self.a.id, a3]).distinct(), john_smith)
+        self.assertQuerysetEqual(Reporter.objects.filter(article__in=[self.a, a3]).distinct(), john_smith)
         self.assertQuerysetEqual(
             Reporter.objects.filter(article__headline__startswith='T'),
             ["<Reporter: John Smith>", "<Reporter: John Smith>"],
             ordered=False
         )
-        self.assertQuerysetEqual(
-            Reporter.objects.filter(article__headline__startswith='T').distinct(),
-            ["<Reporter: John Smith>"])
+        self.assertQuerysetEqual(Reporter.objects.filter(article__headline__startswith='T').distinct(), john_smith)
 
         # Counting in the opposite direction works in conjunction with distinct()
-        self.assertEqual(
-            Reporter.objects.filter(article__headline__startswith='T').count(), 2)
-        self.assertEqual(
-            Reporter.objects.filter(article__headline__startswith='T').distinct().count(), 1)
+        self.assertEqual(Reporter.objects.filter(article__headline__startswith='T').count(), 2)
+        self.assertEqual(Reporter.objects.filter(article__headline__startswith='T').distinct().count(), 1)
 
         # Queries can go round in circles.
         self.assertQuerysetEqual(
@@ -340,23 +310,21 @@ class ManyToOneTests(TestCase):
         )
         self.assertQuerysetEqual(
             Reporter.objects.filter(article__reporter__first_name__startswith='John').distinct(),
-            ["<Reporter: John Smith>"])
-        self.assertQuerysetEqual(
-            Reporter.objects.filter(article__reporter__exact=self.r).distinct(),
-            ["<Reporter: John Smith>"])
+            john_smith
+        )
+        self.assertQuerysetEqual(Reporter.objects.filter(article__reporter__exact=self.r).distinct(), john_smith)
 
         # Check that implied __exact also works.
-        self.assertQuerysetEqual(
-            Reporter.objects.filter(article__reporter=self.r).distinct(),
-            ["<Reporter: John Smith>"])
+        self.assertQuerysetEqual(Reporter.objects.filter(article__reporter=self.r).distinct(), john_smith)
 
         # It's possible to use values() calls across many-to-one relations.
         # (Note, too, that we clear the ordering here so as not to drag the
         # 'headline' field into the columns being used to determine uniqueness)
         d = {'reporter__first_name': 'John', 'reporter__last_name': 'Smith'}
-        self.assertEqual([d],
-            list(Article.objects.filter(reporter=self.r).distinct().order_by()
-                 .values('reporter__first_name', 'reporter__last_name')))
+        qs = Article.objects.filter(
+            reporter=self.r,
+        ).distinct().order_by().values('reporter__first_name', 'reporter__last_name')
+        self.assertEqual([d], list(qs))
 
     def test_select_related(self):
         # Check that Article.objects.select_related().dates() works properly when
@@ -366,55 +334,54 @@ class ManyToOneTests(TestCase):
         r2 = Reporter.objects.create(first_name='John', last_name='Kass', email='jkass@tribune.com')
         Article.objects.create(headline='First', pub_date=datetime.date(1980, 4, 23), reporter=r1)
         Article.objects.create(headline='Second', pub_date=datetime.date(1980, 4, 23), reporter=r2)
-        self.assertEqual(list(Article.objects.select_related().dates('pub_date', 'day')),
-            [
-                datetime.date(1980, 4, 23),
-                datetime.date(2005, 7, 27),
-            ])
-        self.assertEqual(list(Article.objects.select_related().dates('pub_date', 'month')),
-            [
-                datetime.date(1980, 4, 1),
-                datetime.date(2005, 7, 1),
-            ])
-        self.assertEqual(list(Article.objects.select_related().dates('pub_date', 'year')),
-            [
-                datetime.date(1980, 1, 1),
-                datetime.date(2005, 1, 1),
-            ])
+        self.assertEqual(
+            list(Article.objects.select_related().dates('pub_date', 'day')),
+            [datetime.date(1980, 4, 23), datetime.date(2005, 7, 27)]
+        )
+        self.assertEqual(
+            list(Article.objects.select_related().dates('pub_date', 'month')),
+            [datetime.date(1980, 4, 1), datetime.date(2005, 7, 1)]
+        )
+        self.assertEqual(
+            list(Article.objects.select_related().dates('pub_date', 'year')),
+            [datetime.date(1980, 1, 1), datetime.date(2005, 1, 1)]
+        )
 
     def test_delete(self):
-        self.r.article_set.create(headline="John's second story",
-                                  pub_date=datetime.date(2005, 7, 29))
-        self.r2.article_set.create(headline="Paul's story",
-                                   pub_date=datetime.date(2006, 1, 17))
-        Article.objects.create(id=None, headline="Third article",
-                               pub_date=datetime.date(2005, 7, 27), reporter_id=self.r.id)
-        Article.objects.create(id=None, headline="Fourth article",
-                               pub_date=datetime.date(2005, 7, 27), reporter_id=str(self.r.id))
+        self.r.article_set.create(headline="John's second story", pub_date=datetime.date(2005, 7, 29))
+        self.r2.article_set.create(headline="Paul's story", pub_date=datetime.date(2006, 1, 17))
+        Article.objects.create(headline="Third article", pub_date=datetime.date(2005, 7, 27), reporter_id=self.r.id)
+        Article.objects.create(
+            headline="Fourth article",
+            pub_date=datetime.date(2005, 7, 27),
+            reporter_id=str(self.r.id),
+        )
         # If you delete a reporter, his articles will be deleted.
-        self.assertQuerysetEqual(Article.objects.all(),
+        self.assertQuerysetEqual(
+            Article.objects.all(),
             [
                 "<Article: Fourth article>",
                 "<Article: John's second story>",
                 "<Article: Paul's story>",
                 "<Article: Third article>",
                 "<Article: This is a test>",
-            ])
-        self.assertQuerysetEqual(Reporter.objects.order_by('first_name'),
-            [
-                "<Reporter: John Smith>",
-                "<Reporter: Paul Jones>",
-            ])
+            ]
+        )
+        self.assertQuerysetEqual(
+            Reporter.objects.order_by('first_name'),
+            ["<Reporter: John Smith>", "<Reporter: Paul Jones>"]
+        )
         self.r2.delete()
-        self.assertQuerysetEqual(Article.objects.all(),
+        self.assertQuerysetEqual(
+            Article.objects.all(),
             [
                 "<Article: Fourth article>",
                 "<Article: John's second story>",
                 "<Article: Third article>",
                 "<Article: This is a test>",
-            ])
-        self.assertQuerysetEqual(Reporter.objects.order_by('first_name'),
-                                 ["<Reporter: John Smith>"])
+            ]
+        )
+        self.assertQuerysetEqual(Reporter.objects.order_by('first_name'), ["<Reporter: John Smith>"])
         # You can delete using a JOIN in the query.
         Reporter.objects.filter(article__headline__startswith='This').delete()
         self.assertQuerysetEqual(Reporter.objects.all(), [])
@@ -423,33 +390,35 @@ class ManyToOneTests(TestCase):
     def test_explicit_fk(self):
         # Create a new Article with get_or_create using an explicit value
         # for a ForeignKey.
-        a2, created = Article.objects.get_or_create(id=None,
-                                                    headline="John's second test",
-                                                    pub_date=datetime.date(2011, 5, 7),
-                                                    reporter_id=self.r.id)
+        a2, created = Article.objects.get_or_create(
+            headline="John's second test",
+            pub_date=datetime.date(2011, 5, 7),
+            reporter_id=self.r.id,
+        )
         self.assertTrue(created)
         self.assertEqual(a2.reporter.id, self.r.id)
 
         # You can specify filters containing the explicit FK value.
         self.assertQuerysetEqual(
             Article.objects.filter(reporter_id__exact=self.r.id),
-            [
-                "<Article: John's second test>",
-                "<Article: This is a test>",
-            ])
+            ["<Article: John's second test>", "<Article: This is a test>"]
+        )
 
         # Create an Article by Paul for the same date.
-        a3 = Article.objects.create(id=None, headline="Paul's commentary",
-                                    pub_date=datetime.date(2011, 5, 7),
-                                    reporter_id=self.r2.id)
+        a3 = Article.objects.create(
+            headline="Paul's commentary",
+            pub_date=datetime.date(2011, 5, 7),
+            reporter_id=self.r2.id,
+        )
         self.assertEqual(a3.reporter.id, self.r2.id)
 
         # Get should respect explicit foreign keys as well.
-        self.assertRaises(MultipleObjectsReturned,
-                          Article.objects.get, reporter_id=self.r.id)
-        self.assertEqual(repr(a3),
-                         repr(Article.objects.get(reporter_id=self.r2.id,
-                                             pub_date=datetime.date(2011, 5, 7))))
+        with self.assertRaises(MultipleObjectsReturned):
+            Article.objects.get(reporter_id=self.r.id)
+        self.assertEqual(
+            repr(a3),
+            repr(Article.objects.get(reporter_id=self.r2.id, pub_date=datetime.date(2011, 5, 7)))
+        )
 
     def test_deepcopy_and_circular_references(self):
         # Regression for #12876 -- Model methods that include queries that
@@ -468,29 +437,21 @@ class ManyToOneTests(TestCase):
         self.assertIs(r1.article_set.__class__, r2.article_set.__class__)
 
     def test_create_relation_with_ugettext_lazy(self):
-        reporter = Reporter.objects.create(first_name='John',
-                                           last_name='Smith',
-                                           email='john.smith@example.com')
+        reporter = Reporter.objects.create(first_name='John', last_name='Smith', email='john.smith@example.com')
         lazy = ugettext_lazy('test')
-        reporter.article_set.create(headline=lazy,
-                                    pub_date=datetime.date(2011, 6, 10))
+        reporter.article_set.create(headline=lazy, pub_date=datetime.date(2011, 6, 10))
         notlazy = six.text_type(lazy)
         article = reporter.article_set.get()
         self.assertEqual(article.headline, notlazy)
 
     def test_values_list_exception(self):
         expected_message = "Cannot resolve keyword 'notafield' into field. Choices are: %s"
-
-        self.assertRaisesMessage(FieldError,
-                                 expected_message % ', '.join(sorted(f.name for f in Reporter._meta.get_fields())),
-                                 Article.objects.values_list,
-                                 'reporter__notafield')
-        self.assertRaisesMessage(
-            FieldError,
-            expected_message % ', '.join(['EXTRA'] + sorted(f.name for f in Article._meta.get_fields())),
-            Article.objects.extra(select={'EXTRA': 'EXTRA_SELECT'}).values_list,
-            'notafield'
-        )
+        reporter_fields = ', '.join(sorted(f.name for f in Reporter._meta.get_fields()))
+        with self.assertRaisesMessage(FieldError, expected_message % reporter_fields):
+            Article.objects.values_list('reporter__notafield')
+        article_fields = ', '.join(['EXTRA'] + sorted(f.name for f in Article._meta.get_fields()))
+        with self.assertRaisesMessage(FieldError, expected_message % article_fields):
+            Article.objects.extra(select={'EXTRA': 'EXTRA_SELECT'}).values_list('notafield')
 
     def test_fk_assignment_and_related_object_cache(self):
         # Tests of ForeignKey assignment and the related-object cache (see #6886).
@@ -526,16 +487,20 @@ class ManyToOneTests(TestCase):
         p = Parent.objects.get(name="Parent")
         self.assertIsNone(p.bestchild)
 
-        # Assigning None fails: Child.parent is null=False.
-        self.assertRaises(ValueError, setattr, c, "parent", None)
+        # Assigning None will not fail: Child.parent is null=False.
+        setattr(c, "parent", None)
 
         # You also can't assign an object of the wrong type here
-        self.assertRaises(ValueError, setattr, c, "parent", First(id=1, second=1))
+        with self.assertRaises(ValueError):
+            setattr(c, "parent", First(id=1, second=1))
 
-        # Nor can you explicitly assign None to Child.parent during object
-        # creation (regression for #9649).
-        self.assertRaises(ValueError, Child, name='xyzzy', parent=None)
-        self.assertRaises(ValueError, Child.objects.create, name='xyzzy', parent=None)
+        # You can assign None to Child.parent during object creation.
+        Child(name='xyzzy', parent=None)
+
+        # But when trying to save a Child with parent=None, the database will
+        # raise IntegrityError.
+        with self.assertRaises(IntegrityError), transaction.atomic():
+            Child.objects.create(name='xyzzy', parent=None)
 
         # Creation using keyword argument should cache the related object.
         p = Parent.objects.get(name="Parent")
@@ -559,6 +524,15 @@ class ManyToOneTests(TestCase):
         self.assertIsNot(c.parent, p)
         self.assertEqual(c.parent, p)
 
+    def test_fk_to_bigautofield(self):
+        ch = City.objects.create(name='Chicago')
+        District.objects.create(city=ch, name='Far South')
+        District.objects.create(city=ch, name='North')
+
+        ny = City.objects.create(name='New York', id=2 ** 33)
+        District.objects.create(city=ny, name='Brooklyn')
+        District.objects.create(city=ny, name='Manhattan')
+
     def test_multiple_foreignkeys(self):
         # Test of multiple ForeignKeys to the same model (bug #7125).
         c1 = Category.objects.create(name='First')
@@ -583,7 +557,8 @@ class ManyToOneTests(TestCase):
 
         p = Parent.objects.create(name="Parent")
         c = Child.objects.create(name="Child", parent=p)
-        self.assertRaises(ValueError, Child.objects.create, name="Grandchild", parent=c)
+        with self.assertRaises(ValueError):
+            Child.objects.create(name="Grandchild", parent=c)
 
     def test_fk_instantiation_outside_model(self):
         # Regression for #12190 -- Should be able to instantiate a FK outside
@@ -605,6 +580,7 @@ class ManyToOneTests(TestCase):
         with self.assertNumQueries(1):
             self.assertEqual(th.child_set.count(), 0)
 
+    @ignore_warnings(category=RemovedInDjango20Warning)  # for use_for_related_fields deprecation
     def test_related_object(self):
         public_school = School.objects.create(is_public=True)
         public_student = Student.objects.create(school=public_school)
@@ -613,10 +589,7 @@ class ManyToOneTests(TestCase):
         private_student = Student.objects.create(school=private_school)
 
         # Only one school is available via all() due to the custom default manager.
-        self.assertQuerysetEqual(
-            School.objects.all(),
-            ["<School: School object>"]
-        )
+        self.assertQuerysetEqual(School.objects.all(), ["<School: School object>"])
 
         self.assertEqual(public_student.school, public_school)
 
@@ -628,12 +601,23 @@ class ManyToOneTests(TestCase):
         # If the manager is marked "use_for_related_fields", it'll get used instead
         # of the "bare" queryset. Usually you'd define this as a property on the class,
         # but this approximates that in a way that's easier in tests.
-        School.objects.use_for_related_fields = True
+        School._default_manager.use_for_related_fields = True
         try:
             private_student = Student.objects.get(pk=private_student.pk)
-            self.assertRaises(School.DoesNotExist, lambda: private_student.school)
+            with self.assertRaises(School.DoesNotExist):
+                private_student.school
         finally:
-            School.objects.use_for_related_fields = False
+            School._default_manager.use_for_related_fields = False
+
+        School._meta.base_manager_name = 'objects'
+        School._meta._expire_cache()
+        try:
+            private_student = Student.objects.get(pk=private_student.pk)
+            with self.assertRaises(School.DoesNotExist):
+                private_student.school
+        finally:
+            School._meta.base_manager_name = None
+            School._meta._expire_cache()
 
     def test_hasattr_related_object(self):
         # The exception raised on attribute access when a related object
